@@ -6,7 +6,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 use Moo;
 use Config;
@@ -267,7 +267,7 @@ Chart::Kaleido - Base class for Chart::Kaleido
 
 =head1 VERSION
 
-version 0.010
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -278,9 +278,9 @@ version 0.010
     { "data": [{"y": [1,2,1]}] }
     END_OF_TEXT
 
-    my $kaleido = Chart::Plotly::Kaleido->new();
+    my $kaleido = Chart::Kaleido::Plotly->new();
     $kaleido->save( file => "foo.png", plot => $data,
-                    widht => 1024, height => 768 );
+                    width => 1024, height => 768 );
 
 =head1 DESCRIPTION
 
@@ -311,7 +311,7 @@ Gabor Szabo <gabor@szabgab.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020-2021 by Stephan Loyd.
+This software is copyright (c) 2020-2022 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
